@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
+# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,9 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from copy import deepcopy
+
+from six.moves.urllib import parse
+
+from monascaclient.apiclient import base
 from monascaclient.common import monasca_manager
-from monascaclient.openstack.common.apiclient import base
-from monascaclient.openstack.common.py3kcompat import urlutils
 
 
 class Metrics(base.Resource):
@@ -29,19 +32,20 @@ class MetricsManager(monasca_manager.MonascaManager):
     base_url = '/metrics'
 
     def create(self, **kwargs):
+        local_kwargs = deepcopy(kwargs)
         """Create a metric."""
         url_str = self.base_url
         newheaders = self.get_headers()
-        if 'tenant_id' in kwargs:
-            url_str = url_str + '?tenant_id=%s' % kwargs['tenant_id']
-            del kwargs['tenant_id']
-        if 'jsonbody' in kwargs:
+        if 'tenant_id' in local_kwargs:
+            url_str = url_str + '?tenant_id=%s' % local_kwargs['tenant_id']
+            del local_kwargs['tenant_id']
+        if 'jsonbody' in local_kwargs:
             resp, body = self.client.json_request('POST', url_str,
-                                                  data=kwargs['jsonbody'],
+                                                  data=local_kwargs['jsonbody'],
                                                   headers=newheaders)
         else:
             resp, body = self.client.json_request('POST', url_str,
-                                                  data=kwargs,
+                                                  data=local_kwargs,
                                                   headers=newheaders)
         return resp
 
@@ -54,7 +58,7 @@ class MetricsManager(monasca_manager.MonascaManager):
             kwargs['dimensions'] = dimstr
 
         if kwargs:
-            url_str = url_str + '?%s' % urlutils.urlencode(kwargs, True)
+            url_str = url_str + '?%s' % parse.urlencode(kwargs, True)
         # print url_str
         resp, body = self.client.json_request(
             'GET', url_str, headers=newheaders)
@@ -69,7 +73,7 @@ class MetricsManager(monasca_manager.MonascaManager):
             kwargs['dimensions'] = dimstr
 
         if kwargs:
-            url_str = url_str + '?%s' % urlutils.urlencode(kwargs, True)
+            url_str = url_str + '?%s' % parse.urlencode(kwargs, True)
         # print url_str
         resp, body = self.client.json_request(
             'GET', url_str, headers=newheaders)
@@ -84,7 +88,7 @@ class MetricsManager(monasca_manager.MonascaManager):
             kwargs['dimensions'] = dimstr
 
         if kwargs:
-            url_str = url_str + '?%s' % urlutils.urlencode(kwargs, True)
+            url_str = url_str + '?%s' % parse.urlencode(kwargs, True)
         # print url_str
         resp, body = self.client.json_request(
             'GET', url_str, headers=newheaders)
@@ -99,8 +103,30 @@ class MetricsManager(monasca_manager.MonascaManager):
             kwargs['dimensions'] = dimstr
 
         if kwargs:
-            url_str = url_str + '?%s' % urlutils.urlencode(kwargs, True)
+            url_str = url_str + '?%s' % parse.urlencode(kwargs, True)
         # print url_str
         resp, body = self.client.json_request(
             'GET', url_str, headers=newheaders)
         return body['elements'] if type(body) is dict else body
+
+    def list_dimension_names(self, **kwargs):
+        """Get a list of metric dimension names."""
+        url_str = self.base_url + '/dimensions/names'
+        new_headers = self.get_headers()
+        if kwargs:
+            url_str += '?%s' % parse.urlencode(kwargs, True)
+        # print url_str
+        resp, body = self.client.json_request(
+            'GET', url_str, headers=new_headers)
+        return body['elements'] if type(body) is dict else body
+
+    def list_dimension_values(self, **kwargs):
+        """Get a list of metric dimension values."""
+        url_str = self.base_url + '/dimensions/names/values'
+        new_headers = self.get_headers()
+        if kwargs:
+            url_str += '?%s' % parse.urlencode(kwargs, True)
+        # print url_str
+        resp, body = self.client.json_request(
+            'GET', url_str, headers=new_headers)
+        return body['elements'] if type(body) is dict else body
