@@ -15,9 +15,10 @@
 
 from copy import deepcopy
 
+from six.moves.urllib import parse
+
+from monascaclient.apiclient import base
 from monascaclient.common import monasca_manager
-from monascaclient.openstack.common.apiclient import base
-from monascaclient.openstack.common.py3kcompat import urlutils
 
 
 class Notifications(base.Resource):
@@ -51,7 +52,7 @@ class NotificationsManager(monasca_manager.MonascaManager):
         newheaders = self.get_headers()
         url_str = self.base_url
         if kwargs:
-            url_str = url_str + '?%s' % urlutils.urlencode(kwargs, True)
+            url_str = url_str + '?%s' % parse.urlencode(kwargs, True)
 
         resp, body = self.client.json_request('GET', url_str,
                                               headers=newheaders)
